@@ -4,13 +4,13 @@ import abc
 from typing import Any, Dict, Optional, Type
 
 from blacksmith.domain.exceptions import HTTPError
-from blacksmith.domain.model.http import HTTPRequest, HTTPResponse
-from blacksmith.typing import ClientName, HttpMethod, Path
+from blacksmith.domain.model.http import HTTPRequest, HTTPResponse, HTTPTimeout
+from blacksmith.typing import ClientName, Path
 
 from .base import AsyncHTTPMiddleware, AsyncMiddleware
 
 
-class AbtractTraceContext(abc.ABC):
+class AbstractTraceContext(abc.ABC):
     """
     Interface of the trace context for the middleware.
 
@@ -27,21 +27,21 @@ class AbtractTraceContext(abc.ABC):
         """Create a trace span for the current context."""
 
     @abc.abstractmethod
-    def tag(self, key: str, value: str) -> "AbtractTraceContext":
+    def tag(self, key: str, value: str) -> "AbstractTraceContext":
         """Tag the span"""
 
     @abc.abstractmethod
     def annotate(
         self, value: Optional[str], ts: Optional[float] = None
-    ) -> "AbtractTraceContext":
+    ) -> "AbstractTraceContext":
         """Annotate the span"""
 
     @abc.abstractmethod
-    def __enter__(self) -> "AbtractTraceContext":
+    def __enter__(self) -> "AbstractTraceContext":
         """Make the created trace span of the current context the active span."""
 
     @abc.abstractmethod
-    def __exit__(self, *exc: Any):
+    def __exit__(self, *exc: Any) -> None:
         """
         Ends the created trace span of the context, it parents become the active span.
         """
@@ -54,15 +54,18 @@ class AsyncZipkinMiddleware(AsyncHTTPMiddleware):
     :param trace: A deferred context manager that manage the trace span stack.
     """
 
-    def __init__(self, trace: Type[AbtractTraceContext]) -> None:
+    def __init__(self, trace: Type[AbstractTraceContext]) -> None:
         self.trace = trace
 
     def __call__(self, next: AsyncMiddleware) -> AsyncMiddleware:
         async def handle(
-            req: HTTPRequest, method: HttpMethod, client_name: ClientName, path: Path
+            req: HTTPRequest,
+            client_name: ClientName,
+            path: Path,
+            timeout: HTTPTimeout,
         ) -> HTTPResponse:
 
-            name = f"{method} {path.format(**req.path)}"
+            name = f"{req.method} {path.format(**req.path)}"
 
             with self.trace(name, "CLIENT") as child_span:
                 headers = self.trace.make_headers()
@@ -74,7 +77,7 @@ class AsyncZipkinMiddleware(AsyncHTTPMiddleware):
                 if req.querystring:
                     child_span.tag("http.querystring", repr(req.querystring))
                 try:
-                    resp = await next(req, method, client_name, path)
+                    resp = await next(req, client_name, path, timeout)
                 except HTTPError as exc:
                     child_span.tag("http.status_code", str(exc.response.status_code))
                     child_span.tag("error", "true")
